@@ -40,3 +40,8 @@ class Setting(object):
         except Exception as e:
             raise e
 
+    def set_data(self, section, my_setting, data):
+        """
+        修改config
+        """
+        self.cfg.set(section, my_setting, data)
